@@ -9,7 +9,7 @@ class ImageCache:
 
     EXTENSIONS = ['.png','.jpg','.jpeg','.heif','.heic']
     EXIF_TO_FIELD = {'EXIF FNumber': 'f_number',
-                     'EXIF Make': 'make',
+                     'Image Make': 'make',
                      'Image Model': 'model',
                      'EXIF ExposureTime': 'exposure_time',
                      'EXIF ISOSpeedRatings': 'iso',
@@ -22,7 +22,7 @@ class ImageCache:
                      'IPTC Object Name': 'title'}
 
 
-    def __init__(self, picture_dir, db_file, geo_reverse, portrait_pairs=False):
+    def __init__(self, picture_dir, follow_links, db_file, geo_reverse, portrait_pairs=False):
         # TODO these class methods will crash if Model attempts to instantiate this using a
         # different version from the latest one - should this argument be taken out?
         self.__modified_folders = []
@@ -32,6 +32,7 @@ class ImageCache:
         self.__logger = logging.getLogger("image_cache.ImageCache")
         self.__logger.debug('Creating an instance of ImageCache')
         self.__picture_dir = picture_dir
+        self.__follow_links = follow_links
         self.__db_file = db_file
         self.__geo_reverse = geo_reverse
         self.__portrait_pairs = portrait_pairs #TODO have a function to turn this on and off?
@@ -95,9 +96,9 @@ class ImageCache:
             self.__logger.debug('Inserting: %s', file)
             self.__insert_file(file)
 
-        # If we've process all files in the current collection, update the cached folder mod times
+        # If we've process all files in the current collection, update the cached folder info
         if not self.__modified_files:
-            self.__update_folder_modtimes(self.__modified_folders)
+            self.__update_folder_info(self.__modified_folders)
             self.__modified_folders.clear()
 
         # If looping is still not paused, remove any files or folders from the db that are no longer on disk
@@ -346,10 +347,15 @@ class ImageCache:
             self.__db.execute('INSERT INTO db_info VALUES(?)', (required_db_schema_version,))
 
 
+    # --- Returns a set of folders matching any of
+    #     - Found on disk, but not currently in the 'folder' table
+    #     - Found on disk, but newer than the associated record in the 'folder' table
+    #     - Found on disk, but flagged as 'missing' in the 'folder' table
+    # --- Note that all folders returned currently exist on disk
     def __get_modified_folders(self):
         out_of_date_folders = []
         sql_select = "SELECT * FROM folder WHERE name = ?"
-        for dir in [d[0] for d in os.walk(self.__picture_dir)]:
+        for dir in [d[0] for d in os.walk(self.__picture_dir, followlinks=self.__follow_links)]:
             mod_tm = int(os.stat(dir).st_mtime)
             found = self.__db.execute(sql_select, (dir,)).fetchone()
             if not found or found['last_modified'] < mod_tm or found['missing'] == 1:
@@ -403,9 +409,9 @@ class ImageCache:
         self.__db.execute(meta_insert, vals)
 
 
-    def __update_folder_modtimes(self, folder_collection):
+    def __update_folder_info(self, folder_collection):
         update_data = []
-        sql = "UPDATE folder SET last_modified = ? WHERE name = ?"
+        sql = "UPDATE folder SET last_modified = ?, missing = 0 WHERE name = ?"
         for folder, modtime in folder_collection:
             update_data.append((modtime, folder))
         self.__db.executemany(sql, update_data)
@@ -454,19 +460,20 @@ class ImageCache:
         e['orientation'] = exifs.get_orientation()
 
         width, height = exifs.get_size()
-        if e['orientation'] in (5, 6, 7, 8):
+        ext = os.path.splitext(file_path_name)[1].lower()
+        if ext not in ('.heif','.heic') and e['orientation'] in (5, 6, 7, 8):
             width, height = height, width # swap values
         e['width'] = width
         e['height'] = height
 
 
         e['f_number'] = exifs.get_exif('EXIF FNumber')
-        e['make'] = exifs.get_exif('EXIF Make')
+        e['make'] = exifs.get_exif('Image Make')
         e['model'] = exifs.get_exif('Image Model')
         e['exposure_time'] = exifs.get_exif('EXIF ExposureTime')
         e['iso'] =  exifs.get_exif('EXIF ISOSpeedRatings')
         e['focal_length'] =  exifs.get_exif('EXIF FocalLength')
-        e['rating'] = exifs.get_exif('EXIF Rating')
+        e['rating'] = exifs.get_exif('Image Rating')
         e['lens'] = exifs.get_exif('EXIF LensModel')
         e['exif_datetime'] = None
         val = exifs.get_exif('EXIF DateTimeOriginal')
@@ -500,7 +507,7 @@ class ImageCache:
 
 # If being executed (instead of imported), kick it off...
 if __name__ == "__main__":
-    cache = ImageCache(picture_dir='/home/pi/Pictures', db_file='/home/pi/db.db3', geo_reverse=None)
+    cache = ImageCache(picture_dir='/home/pi/Pictures', follow_links=False, db_file='/home/pi/db.db3', geo_reverse=None)
     #cache.update_cache()
     # items = cache.query_cache("make like '%google%'", "exif_datetime asc")
     #info = cache.get_file_info(12)
