@@ -8,7 +8,7 @@ import logging
 import os
 import numpy as np
 from PIL import Image, ImageFilter, ImageFile
-from picframe import mat_image
+from picframe import mat_image, get_image_meta
 from datetime import datetime
 
 # supported display modes for display switch
@@ -173,29 +173,6 @@ class ViewerDisplay:
     def clock_is_on(self, val):
         self.__show_clock = val
 
-    def __check_heif_then_open(self, fname):
-        ext = os.path.splitext(fname)[1].lower()
-        if ext in ('.heif','.heic'):
-            try:
-                import pyheif
-
-                heif_file = pyheif.read(fname)
-                image = Image.frombytes(heif_file.mode, heif_file.size, heif_file.data,
-                                        "raw", heif_file.mode, heif_file.stride)
-                if image.mode not in ("RGB", "RGBA"):
-                    image = image.convert("RGB")
-                return image
-            except:
-                self.__logger.warning("Failed attempt to convert %s \n** Have you installed pyheif? **", fname)
-        else:
-            try:
-                image = Image.open(fname)
-                if image.mode not in ("RGB", "RGBA"): # mat system needs RGB or more
-                    image = image.convert("RGB")
-            except: # for whatever reason
-                image = None
-            return image
-
     # Concatenate the specified images horizontally. Clip the taller
     # image to the height of the shorter image.
     def __create_image_pair(self, im1, im2):
@@ -210,7 +187,11 @@ class ViewerDisplay:
         dst.paste(im2, (im1.width + sep, 0))
         return dst
 
-    def __orientate_image(self, im, orientation):
+    def __orientate_image(self, im, pic):
+        ext = os.path.splitext(pic.fname)[1].lower()
+        if ext  in ('.heif','.heic'): # heif and heic images are converted to PIL.Image obects and are alway in correct orienation
+            return im
+        orientation = pic.orientation
         if orientation == 2:
             im = im.transpose(Image.FLIP_LEFT_RIGHT)
         elif orientation == 3:
@@ -272,15 +253,18 @@ class ViewerDisplay:
 
             # Load the image(s) and correct their orientation as necessary
             if pics[0]:
-                im = self.__check_heif_then_open(pics[0].fname)
-                if pics[0].orientation != 1:
-                     im = self.__orientate_image(im, pics[0].orientation)
+                im = get_image_meta.GetImageMeta.get_image_object(pics[0].fname)
                 if im is None:
                     return None
+                if pics[0].orientation != 1:
+                    im = self.__orientate_image(im, pics[0])
+                
             if pics[1]:
-                im2 = self.__check_heif_then_open(pics[1].fname)
+                im2 = get_image_meta.GetImageMeta.get_image_object(pics[1].fname)
+                if im2 is None:
+                    return None
                 if pics[1].orientation != 1:
-                     im2 = self.__orientate_image(im2, pics[1].orientation)
+                     im2 = self.__orientate_image(im2, pics[1])
 
             screen_aspect, image_aspect, diff_aspect = self.__get_aspect_diff(size, im.size)
 
